pub struct Swap {
pub authority: Pubkey,
pub user_transfer_authority: Pubkey,
pub source_info: Pubkey,
pub destination_info: Pubkey,
pub swap_source: Pubkey,
pub swap_destination: Pubkey,
pub pool_mint: Pubkey,
pub fee_account: Pubkey,
pub token_program: Pubkey,
pub pyth_account: Pubkey,
pub pyth_pc_account: Pubkey,
}Expand description
Generated client accounts for Swap.
Fields
source_info: Pubkeydestination_info: Pubkeyswap_source: Pubkeyswap_destination: Pubkeypool_mint: Pubkeyfee_account: Pubkeytoken_program: Pubkeypyth_account: Pubkeypyth_pc_account: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Swapwhere
Pubkey: BorshSerialize,
impl BorshSerialize for Swapwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for Swap
impl ToAccountMetas for Swap
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Swap
impl RefUnwindSafe for Swap
impl Send for Swap
impl Sync for Swap
impl Unpin for Swap
impl UnwindSafe for Swap